import React from 'react';
import PropTypes from 'prop-types';
import ColorPicker from './ColorPicker';
import { createComponent } from '@cloudflare/style-container';
var CoverDiv = createComponent(() => ({
  position: 'fixed',
  top: '0px',
  right: '0px',
  bottom: '0px',
  left: '0px'
}), 'div');
var PopoverDiv = createComponent(() => ({
  position: 'absolute',
  zIndex: '2'
}), 'div');
var FakeInputDiv = createComponent(_ref => {
  var {
    theme,
    disabled
  } = _ref;
  return {
    zIndex: 0,
    width: '100%',
    height: '2.26667rem',
    margin: '0 0 0.75rem',
    padding: '.6em .9em',
    borderBottom: "1px solid ".concat(theme.colors.gray[5]),
    borderTop: "1px solid ".concat(theme.colors.gray[5]),
    borderLeft: "1px solid ".concat(theme.colors.gray[5]),
    borderRight: "1px solid ".concat(theme.colors.gray[5]),
    borderRadius: '2px',
    flex: 'initial',
    verticalAlign: 'middle',
    fontFamily: theme.fontFamily,
    fontSize: '0.86667rem',
    background: theme.colors.background,
    color: theme.colors.gray[1],
    outline: 'none',
    transition: 'border-color 0.2s ease',
    textIndent: 'initial',
    '&:hover': {
      borderColor: disabled ? null : theme.colors.blue[4]
    },
    '&:disabled': {
      background: theme.colors.background,
      color: theme.colors.gray[1]
    }
  };
}, 'div');
var ColorDisplayDiv = createComponent(_ref2 => {
  var {
    theme,
    color,
    defaultColor
  } = _ref2;
  return {
    background: color || defaultColor,
    height: '100%',
    width: '100%',
    borderWidth: '1px',
    borderStyle: 'solid',
    borderColor: theme.colors.gray[5]
  };
}, 'div');

class ColorPickerInput extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      displayColorPicker: false
    };
    this.handleChange = this.handleChange.bind(this);
    this.handleClose = this.handleClose.bind(this);
    this.handleClick = this.handleClick.bind(this);
  }

  handleClick(e) {
    e.preventDefault();
    this.setState({
      displayColorPicker: !this.state.displayColorPicker
    });
  }

  handleClose() {
    this.setState({
      displayColorPicker: false
    });
  }

  handleChange(color) {
    this.props.onChange({
      value: color.hex
    });
  }

  render() {
    var {
      defaultEmptyValue,
      value,
      disabled
    } = this.props;
    return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(FakeInputDiv, {
      onClick: disabled ? () => null : this.handleClick,
      disabled: disabled
    }, /*#__PURE__*/React.createElement(ColorDisplayDiv, {
      color: value,
      defaultColor: defaultEmptyValue
    })), this.state.displayColorPicker ? /*#__PURE__*/React.createElement(PopoverDiv, null, /*#__PURE__*/React.createElement(CoverDiv, {
      onClick: this.handleClose
    }), /*#__PURE__*/React.createElement(ColorPicker, {
      color: value,
      onChange: disabled ? () => null : this.handleChange
    })) : null);
  }

}

ColorPickerInput.propTypes = {
  disabled: PropTypes.bool,
  defaultEmptyValue: PropTypes.string,
  onChange: PropTypes.func,
  value: PropTypes.string
};
export default ColorPickerInput;